@@ -20,7 +20,7 @@ class CommentableContent(Entity):
 def test_commentable_interface():
     assert is_commentable(CommentableContent)
 
-    instance = CommentableContent(name='test instance')
+    instance = CommentableContent(name="test instance")
     assert not is_commentable(instance)  # not in DB: no id
 
     instance.id = 42
@@ -30,7 +30,6 @@ def test_commentable_interface():
 
 
 def test_cannot_register_non_entities():
-
     class Dummy(object):
         pass
 
@@ -39,14 +38,14 @@ def test_cannot_register_non_entities():
 
 
 def test_default_ordering(app, db):
-    commentable = CommentableContent(name='commentable objet')
+    commentable = CommentableContent(name="commentable objet")
     db.session.add(commentable)
 
     now = datetime.now()
-    c1 = Comment(entity=commentable, body='comment #1')
+    c1 = Comment(entity=commentable, body="comment #1")
     c1.created_at = now - timedelta(10)
     db.session.flush()
-    c2 = Comment(entity=commentable, body='comment #2')
+    c2 = Comment(entity=commentable, body="comment #2")
     c2.created_at = now - timedelta(5)
     db.session.flush()
 
