@@ -3,4 +3,4 @@ from __future__ import absolute_import, division, print_function
 
 from .service import preferences
 
-__all__ = ['preferences']
+__all__ = ["preferences"]
