@@ -1,6 +1,6 @@
 # coding=utf-8
 """Elements to build test cases for an :class:`abilian.app.Application`"""
-from __future__ import absolute_import, print_function, division, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from .base import BaseTestCase, TestConfig
 
