@@ -3,9 +3,12 @@
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
+from typing import ContextManager
+
 from flask.testing import FlaskClient
 from flask_login import login_user, logout_user
 from hyperlink import URL
+from six import text_type
 from sqlalchemy.exc import DatabaseError
 
 from abilian.core.models.subjects import User
@@ -17,15 +20,17 @@ __all__ = (
     "cleanup_db",
     "client_login",
     "login",
+    "path_from_url",
 )
 
 
 def path_from_url(url):
+    url = text_type(url)
     return "/" + "/".join(URL.from_text(url).path)
 
 
 def client_login(client, user):
-    # type: (FlaskClient, User) -> LoginContext
+    # type: (FlaskClient, User) -> ContextManager
 
     class LoginContext(object):
         def __enter__(self):
