@@ -17,7 +17,20 @@ from abilian.web.util import url_for
 
 log = logging.getLogger(__name__)
 
-__all__ = ("Action", "ButtonAction", "FAIcon", "ModalActionMixin", "actions")
+__all__ = (
+    "Action",
+    "ButtonAction",
+    "FAIcon",
+    "DynamicIcon",
+    "ModalActionMixin",
+    "Endpoint",
+    "actions",
+    "ENABLED",
+    "ACTIVE",
+    "DISABLED",
+    "Glyphicon",
+    "getset",
+)
 
 
 class Status(UniqueName):
@@ -619,7 +632,8 @@ class ActionRegistry(object):
     def _state(self):
         return current_app.extensions[self.__EXTENSION_NAME]
 
-    def _init_context(self, sender):
+    @staticmethod
+    def _init_context(sender):
         g.action_context = {}
 
     @property
