@@ -16,10 +16,10 @@ from abilian.web.forms.widgets import TextArea
 class CommentForm(Form):
 
     body = TextAreaField(
-        label=_l('Comment'),
+        label=_l("Comment"),
         validators=[required()],
         filters=(strip,),
-        widget=TextArea(rows=5, resizeable='vertical'),
+        widget=TextArea(rows=5, resizeable="vertical"),
     )
 
     class Meta:
