@@ -12,6 +12,7 @@ import logging
 import re
 from collections import namedtuple
 from datetime import datetime
+from typing import Any, Dict, Text
 
 import bleach
 import sqlalchemy as sa
@@ -137,7 +138,7 @@ class BaseTableView(object):
     show_controls = False
     show_search = None
     paginate = False
-    options = {}
+    options = {}  # type: Dict[Text, Any]
 
     def __init__(self, columns, options=None):
         if self.show_search is None:
@@ -295,7 +296,7 @@ class AjaxMainTableView(object):
 
     show_controls = False
     paginate = True
-    options = {}
+    options = {}  # type: Dict[Text, Any]
 
     def __init__(
         self, columns, ajax_source, search_criterions=(), name=None, options=None
@@ -1335,16 +1336,20 @@ class RichTextWidget(object):
         "p": True,
         "u": True,
     }
+    profile = "standard"
 
-    def __init__(self, allowed_tags=None, template=None):
+    def __init__(self, allowed_tags=None, template=None, profile=None):
         if allowed_tags is not None:
             self.allowed_tags = allowed_tags
         if template is not None:
             self.template = template
+        if profile is not None:
+            self.profile = profile
 
     def __call__(self, field, **kwargs):
         value = kwargs.pop("value") if "value" in kwargs else field._value()
         kwargs.setdefault("allowed_tags", self.allowed_tags)
+        kwargs.setdefault("profile", self.profile)
         return render_template(self.template, field=field, value=value, kw=kwargs)
 
 
